## -----------------------------------------------------------------------------
library(causalTLSE)
data(nsw)

## -----------------------------------------------------------------------------
model1 <- setModel(re78~treat | ~age+re75+ed+married, data=nsw)

## -----------------------------------------------------------------------------
modEx <-  setModel(re78~treat | ~age+I(age^2)+re75+ed*married, data=nsw)

## -----------------------------------------------------------------------------
model1$knots1

## -----------------------------------------------------------------------------
quantile(nsw[nsw$treat==1,'re75'], c(.2,.4,.6,.8), type=1)

## -----------------------------------------------------------------------------
model1

## -----------------------------------------------------------------------------
data(simDat4)
model2 <- setModel(Y~Z |~X1+X2+X3+X4, data=simDat4)
model2$knots0

## -----------------------------------------------------------------------------
model3 <- setModel(re78~treat | ~age+re75+ed+married, data=nsw,
                   userRem=c("ed","age"))
model3

## -----------------------------------------------------------------------------
setModel(re78~treat | ~age+re75+ed+married, data=nsw, knots1=NULL)

## -----------------------------------------------------------------------------
model <- setModel(re78~treat | ~age+re75+ed+married, data=nsw,
                  knots0=list(NA, c(1000,5000,10000), NULL, NA))
print(model, knots=TRUE)

## -----------------------------------------------------------------------------
model <- setModel(re78~treat | ~age+married, data=nsw,
                  nknots=function(n) 2)
fit <- estModel(model)
fit

## -----------------------------------------------------------------------------
summary(fit)

## -----------------------------------------------------------------------------
summary(fit$lm.out)[c("r.squared","adj.r.squared")]

## -----------------------------------------------------------------------------
summary(lm(re78~married, nsw))$r.squared
summary(lm(re78~factor(married)-1, nsw))$r.squared

## -----------------------------------------------------------------------------
pr <- predict(fit, newdata=data.frame(treat=c(1,1,0,0),age=20:23, married=1),
              interval="confidence")
pr

## -----------------------------------------------------------------------------
model1 <- setModel(re78~treat | ~age+re75+ed+married, data=nsw)
fit1 <- estModel(model1)

## ---- fig.show='hold', out.width='50%'----------------------------------------
library(sandwich)
plot(fit1, "ed", col0="darkgreen", col1="darkred", lty0=2, lty1=4,
     legendPos="topleft")
plot(fit1, "age", interval='confidence', level=0.9, vcov.=vcovHC)

## ---- fig.show='hold', out.width='50%'----------------------------------------
plot(fit1, "age", newdata=c(married=1, re75=10000), addToLegend="married", cex=0.8)
plot(fit1, "age", newdata=c(married=0, re75=10000), addToLegend="non-married", cex=0.8)

## ---- fig.align='center', out.width='70%'-------------------------------------
plot(fit1, "age", newdata=c(married=1, re75=10000), addToLegend="married", cex=0.8,
     ylim.=c(3000,10000))
plot(fit1, "age", newdata=c(married=0, re75=10000), addToLegend="non-married", cex=0.8,
     legendPos='topleft', col0="darkgreen", col1="darkred", lty0=4, lty1=5,
     add.=TRUE,)

## ---- fig.show='hold', out.width='50%'----------------------------------------
plot(fit1, "ed", col0="darkgreen", col1="darkred", lty0=2, lty1=4,
     legendPos="topleft", addPoints=TRUE)
plot(fit1, "re75", addPoints=TRUE)

## -----------------------------------------------------------------------------
causal(model1)

## -----------------------------------------------------------------------------
causal(fit1)

## -----------------------------------------------------------------------------
ce <- causal(model1)
summary(ce)

## -----------------------------------------------------------------------------
ce2 <- causal(model1, seType="lm", vcov.=vcovHC, type="HC3")
summary(ce2)

## ---- fig.align='center', out.width='65%'-------------------------------------
plot(ce2, "re75")

## -----------------------------------------------------------------------------
print(model1, knots=TRUE)
model2 <- selTLSE(model1)
print(model2, knots=TRUE)

## -----------------------------------------------------------------------------
causal(model2)

## -----------------------------------------------------------------------------
model3 <- selTLSE(model1, method="BTLSE", crit="BIC")
causal(model3)

## ---- eval=FALSE--------------------------------------------------------------
#  library(texreg)
#  c1 <- causal(model1)
#  c2 <- causal(selTLSE(model1, method="BTLSE"))
#  c3 <- causal(selTLSE(model1, method="FTLSE"))
#  texreg(list(SLSE=c1, BTLSE=c2, FTLSE=c3), table=FALSE, digits=4)

## ---- results='asis', message=FALSE, echo=FALSE-------------------------------
library(texreg)
c1 <- causal(model1)
c2 <- causal(selTLSE(model1, method="BTLSE"))
c3 <- causal(selTLSE(model1, method="FTLSE"))
texreg(list(SLSE=c1, BTLSE=c2, FTLSE=c3), table=FALSE, digits=4)

## ---- eval=FALSE--------------------------------------------------------------
#  c1 <- causalTLSE(model1, selType="SLSE")
#  c2 <- causalTLSE(model1, selType="BTLSE")
#  c3 <- causalTLSE(model1, selType="FTLSE")
#  texreg(list(SLSE=c1, BTLSE=c2, FTLSE=c3), table=FALSE, digits=4)

## ---- results='asis', message=FALSE, echo=FALSE-------------------------------
c1 <- causalTLSE(model1, selType="SLSE")
c2 <- causalTLSE(model1, selType="BTLSE")
c3 <- causalTLSE(model1, selType="FTLSE")
texreg(list(SLSE=c1, BTLSE=c2, FTLSE=c3), table=FALSE, digits=4)

## -----------------------------------------------------------------------------
data(simDat1)
mod <- setModel(Y~Z | ~X, data=simDat1)

## ---- eval=FALSE--------------------------------------------------------------
#  c1 <- causalTLSE(mod, selType="SLSE")
#  c2 <- causalTLSE(mod, selType="BTLSE", selCrit="BIC")
#  c3 <- causalTLSE(mod, selType="FTLSE", selCrit="BIC")
#  texreg(list(SLSE=c1, BTLSE=c2, FTLSE=c3), table=FALSE, digits=4)

## ---- results='asis', message=FALSE, echo=FALSE-------------------------------
c1 <- causalTLSE(mod, selType="SLSE")
c2 <- causalTLSE(mod, selType="BTLSE", selCrit="BIC")
c3 <- causalTLSE(mod, selType="FTLSE", selCrit="BIC")
texreg(list(SLSE=c1, BTLSE=c2, FTLSE=c3), table=FALSE, digits=4)

## ---- out.width='50%', fig.show='hold'----------------------------------------
plot(c1, "X")
curve(1-2*x, -3,3, col="darkgreen", lty=3, lwd=3, add=TRUE)
curve(1+x+x^2, -3,3, col="darkorange", lty=3, lwd=3, add=TRUE)
legend("bottomleft", c("True-treated","True-control"),
       col=c("darkgreen","darkorange"), lty=3, lwd=3, bty='n')
plot(c2, "X")
curve(1-2*x, -3,3, col="darkgreen", lty=3, lwd=3, add=TRUE)
curve(1+x+x^2, -3,3, col="darkorange", lty=3, lwd=3, add=TRUE)
legend("bottomleft", c("True-treated","True-control"),
       col=c("darkgreen","darkorange"), lty=3, lwd=3, bty='n')

## ---- out.width='60%', fig.align='center'-------------------------------------
plot(c1, "X", addPoints=TRUE)

## -----------------------------------------------------------------------------
data(simDat2)
mod <- setModel(Y~Z | ~X, data=simDat2)

## ---- eval=FALSE--------------------------------------------------------------
#  c1 <- causalTLSE(mod, selType="SLSE")
#  c2 <- causalTLSE(mod, selType="BTLSE", selCrit="BIC")
#  c3 <- causalTLSE(mod, selType="BTLSE", selCrit="AIC")
#  texreg(list(SLSE=c1, BTLSE.BIC=c2, BTLSE.AIC=c3), table=FALSE, digits=4)

## ---- results='asis', message=FALSE, echo=FALSE-------------------------------
c1 <- causalTLSE(mod, selType="SLSE")
c2 <- causalTLSE(mod, selType="BTLSE", selCrit="BIC")
c3 <- causalTLSE(mod, selType="BTLSE", selCrit="AIC")
texreg(list(SLSE=c1, BTLSE.BIC=c2, BTLSE.AIC=c3), table=FALSE, digits=4)

## ---- out.width='50%', fig.show='hold'----------------------------------------
plot(c2, "X", legendPos="right", cex=.8)
curve((1-2*x)*(x<=0)+(1+2*x)*(x>0), -3,3,
      col="darkgreen", lty=3, lwd=3, add=TRUE)
curve((1+x)*(x<=-1)+(-1-x)*(x>-1),
      -3,3, col="darkorange", lty=3, lwd=3, add=TRUE)
legend("left", c("True-treated","True-control"),
       col=c("darkgreen","darkorange"), lty=3, lwd=3, bty='n', cex=.8)
plot(c2, "X", addPoints=TRUE, legendPos="topleft", cex=.8)

